module Flashboy
  class Bitfinex < Exchange
    name 'Bitfinex'
    docs 'http://docs.bitfinex.com'
    host 'https://api.bitfinex.com'
    quote_path      { |pair| "v1/pubticker/#{pair}.json" } #ethbtc
    order_book_path { |pair| "v1/book/#{pair}.json" }
    trades_path     { |pair, params| "v1/trades/#{pair}?timestamp=#{params[:start]}" }

    def self.parse_cursor(params)
      { start: params[:start] }
    end

    private

    def formatted_pair(pair)
      currency, base = super(pair)
      "#{currency}#{base}".upcase
    end

    def parse_trades(trades, exchange, pair)
      [*trades].map do |trade|
        {
          global_id: "#{exchange.key}-#{trade[:tid]}",
          type: trade[:type],
          price: trade[:price],
          amount: trade[:amount],
          executed_at: trade[:timestamp]
        }
      end
    end

    def parse_quote(quote, pair)
      {
        bid: quote[:bid],
        last: quote[:last_price],
        ask: quote[:ask],
        volume: quote[:volume],
        timestamp: quote[:timestamp]
      }
    end

    def parse_order_book(order, pair)
      {
        bids: (order[:bids] || []).map{|order| { price: order[:price], amount: order[:amount] } },
        asks: (order[:asks] || []).map{|order| { price: order[:price], amount: order[:amount] } }
      }
    end
  end
end
