module Flashboy
  class Bittrex < Exchange
    name 'Bittrex'
    docs 'https://bittrex.com/Home/Api'
    host 'https://bittrex.com'
    quote_path      { |pair| "api/v1.1/public/getticker?market=#{pair}" } #BTC-ETH
    order_book_path { |pair| "api/v1.1/public/getorderbook?market=#{pair}&type=both&depth=10" }

    private

    def formatted_pair(pair)
      currency, base = super(pair)
      "#{base}-#{currency}".upcase
    end

    def parse_quote(quote, pair)
      data = quote[:result]
      {
        bid: data[:Bid],
        last: data[:Last],
        ask: data[:Ask],
        volume: data[:volume],
        timestamp: data[:timestamp]
      }
    end

    def parse_order_book(order, pair)
      {
        bids: order[:result][:buy].map{|o| { price: o[:Rate], amount: o[:Quantity] } },
        asks: order[:result][:sell].map{|o| { price: o[:Rate], amount: o[:Quantity] } }
      }
    end
  end
end
