module Flashboy
  class Cex < Exchange
    name 'CEX'
    docs 'https://cex.io/rest-api'
    host 'https://cex.io/api'
    quote_path      { |pair| "ticker/#{pair}" } #ETH/BTC
    order_book_path { |pair| "order_book/#{pair}/?depth=10" }
    trades_path     { |pair, params| "trade_history/#{pair}/?since=#{params[:since]}" }

    def self.parse_cursor(params)
      { since: params[:since] }
    end

    private

    def formatted_pair(pair)
      currency, base = super(pair)
      "#{currency}/#{base}".upcase
    end

    def parse_trades(trades, exchange, _pair)
      [*trades].map do |trade|
        {
          global_id: "#{exchange.key}-#{trade[:tid]}",
          type: trade[:type],
          price: trade[:price],
          amount: trade[:amount],
          executed_at: trade[:date]
        }
      end
    end


    def parse_quote(quote, pair)
      {
        bid: quote[:bid],
        last: quote[:last],
        ask: quote[:ask],
        volume: quote[:volume],
        timestamp: quote[:timestamp]
      }
    end

    def parse_order_book(order, pair)
      {
        bids: (order[:bids] || []).map{|(p, a)| { price: p, amount: a } },
        asks: (order[:asks] || []).map{|(p, a)| { price: p, amount: a } }
      }
    end
  end
end
