module Flashboy
  class Gdax < Exchange
    name 'GDAX'
    docs 'https://docs.gdax.com'
    host 'https://api.gdax.com'
    quote_path      { |pair| "products/#{pair}/ticker" } #ETH-BTC
    order_book_path { |pair| "products/#{pair}/book" }
    trades_path     { |pair, params| "products/#{pair}/trades?#{params[:since] ? ('before=' + params[:since].to_s) : ''}" }

    def self.parse_cursor(params)
      { since: params[:since] }
    end

    private

    def formatted_pair(pair)
      currency, base = super(pair)
      "#{currency}-#{base}".upcase
    end

    def parse_trades(trades, exchange, _pair)
      [*trades].map do |trade|
        {
          global_id: "#{exchange.key}-#{trade[:trade_id]}",
          type: trade[:side],
          price: trade[:price],
          amount: trade[:size],
          executed_at: trade[:time]
        }
      end
    end

    def parse_quote(quote, pair)
      {
        bid: quote[:bid],
        last: quote[:price],
        ask: quote[:ask],
        volume: quote[:volume],
        timestamp: quote[:time]
      }
    end

    def parse_order_book(order, pair)
      {
        bids: (order[:bids] || []).map{|order| { price: order[:price], amount: order[:amount] } },
        asks: (order[:asks] || []).map{|order| { price: order[:price], amount: order[:amount] } }
      }
    end
  end
end
