module Flashboy
  class Gemini < Exchange
    name 'Gemini'
    docs 'https://docs.gemini.com/rest-api'
    host 'https://api.gemini.com/v1'
    quote_path      { |pair| "pubticker/#{pair}" } #ethbtc
    order_book_path { |pair| "book/#{pair}?depth=10" }
    trades_path     { |pair, params| "trades/#{pair}#{params[:start] ? ('?since=' + params[:start].to_s) : ''}" }

    def self.parse_cursor(params)
      { start: params[:start] }
    end

    private

    def formatted_pair(pair)
      currency, base = super(pair)
      "#{currency}#{base}".downcase
    end

    def parse_trades(trades, exchange, pair)
      [*trades].map do |trade|
        {
          global_id: "#{exchange.key}-#{trade[:tid]}",
          type: trade[:type],
          price: trade[:price],
          amount: trade[:amount],
          executed_at: trade[:timestamp].to_i
        }
      end
    end

    def parse_quote(quote, pair)
      {
        bid: quote[:bid],
        last: quote[:last],
        ask: quote[:ask],
        volume: (quote[:volume].first || [])[1],
        timestamp: quote[:timestamp]
      }
    end

    def parse_order_book(order, pair)
      order
    end
  end
end
