module Flashboy
  class Kraken < Exchange
    name 'Kraken'
    docs 'https://www.kraken.com/help/api'
    host 'https://api.kraken.com'
    quote_path      { |pair| "0/public/Ticker?pair=#{pair}" } #ETHXBT
    order_book_path { |pair| "0/public/Depth?pair=#{pair}" }
    trades_path     { |pair, params| "0/public/Trades?pair=#{pair}#{params[:since] ? ('&since=' + params[:since].to_s) : ''}" }

    def self.parse_cursor(params)
      { since: params[:since] }
    end

    private

    def formatted_pair(pair)
      currency, base = super(pair).map { |curr| curr.upcase == 'BTC' ? 'XBT' : curr }
      "#{currency}#{base}".upcase
    end

    def parse_trades(trades, exchange, pair)
      last_id = trades[:result][:last]
      pair_id = trades[:result].keys.first
      trades = trades[:result][pair_id]

      [*trades].map do |trade|
        price, amount, time, type = trade
        {
          global_id: "#{exchange.key}-#{time}-#{last_id}",
          type: type == 'b' ? 'buy' : 'sell',
          price: price,
          amount: amount,
          executed_at: time
        }
      end
    end

    def parse_quote(quote, pair)
      data = quote[:result].values.first
      {
        bid: (data[:b] || []).first,
        last: (data[:c] || []).first,
        ask: (data[:a] || []).first,
        volume: (data[:v] || []).first,
        timestamp: nil
      }
    end

    def parse_order_book(order, pair)
      data = order[:result].values.first
      {
        bids: data[:bids].map{|(p,a,t)| { price: p, amount: a } },
        asks: data[:asks].map{|(p,a,t)| { price: p, amount: a } }
      }
    end
  end
end
