module Flashboy
  class Poloniex < Exchange
    name 'Poloniex'
    docs 'https://poloniex.com/support/api/'
    host 'https://poloniex.com'
    quote_path      { |pair| "public?command=returnTicker" } #BTC_ETH
    order_book_path { |pair| "book/#{pair}?depth=10" }
    trades_path do |pair, params|
      url = "public?command=returnTradeHistory&currencyPair=#{pair}"
      url += "&start=#{params[:start]}" unless params[:start].nil?
      url
    end

    def self.parse_cursor(params)
      { start: params[:start] }
    end

    private

    def formatted_pair(pair)
      currency, base = super(pair)
      "#{base}_#{currency}".upcase
    end

    def parse_trades(trades, exchange, _pair)
      [*trades].map do |trade|
        {
          global_id: "#{exchange.key}-#{trade[:globalTradeID]}",
          type: trade[:type],
          price: trade[:rate],
          amount: trade[:amount],
          executed_at: trade[:date]
        }
      end
    end

    def parse_quote(quote, pair)
      data = quote[pair.to_sym]
      {
        bid: data[:highestBid],
        last: data[:last],
        ask: data[:lowestAsk],
        volume: data[:baseVolume],
        timestamp: nil
      }
    end

    def parse_order_book(order, pair)
      order
    end
  end
end
