module Flashboy
  class Quoine < Exchange
    name 'Quoine'
    docs 'https://developers.quoine.com'
    host 'https://api.quoine.com'
    quote_path      { |pair| "products/code/CASH/#{pair}" } #ETHBTC
    order_book_path { |pair| "products/#{pair}/price_levels" }
    trades_path do |pair, params|
      url = "executions?currency_pair_code=#{pair}"
      url += "&timestamp=#{params[:start]}" if params[:start]
      url
    end

    def self.parse_cursor(params)
      { start: params[:start] }
    end

    private

    def formatted_pair(pair)
      currency, base = super(pair)
      "#{currency}#{base}".upcase
    end

    def parse_trades(trades, exchange, pair)
      trades = trades.is_a?(Hash) ? trades[:models] : trades
      [*trades].map do |trade|
        trade.recursively_symbolize_keys!
        {
          global_id: "#{exchange.key}-#{trade[:id]}",
          type: trade[:taker_side],
          price: trade[:price],
          amount: trade[:quantity],
          executed_at: trade[:created_at]
        }
      end
    end

    def parse_quote(quote, pair)
      {
        bid: quote[:market_bid],
        last: quote[:last_traded_price],
        ask: quote[:market_ask],
        volume: quote[:volume_24h],
        timestamp: nil
      }
    end

    def parse_order_book(order, pair)
      {
        bids: [],
        asks: []
      }
    end
  end
end
